[Libreoffice-commits] core.git: sw/source

Mike Kaganski mike.kaganski at collabora.com
Mon Dec 5 10:40:21 UTC 2016


 sw/source/core/layout/tabfrm.cxx |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit 9d3366c4c62efa4260c1b11d4b53d5982d6fac48
Author: Mike Kaganski <mike.kaganski at collabora.com>
Date:   Mon Dec 5 13:30:22 2016 +0300

    Fix a typo
    
    Cf. comment for #i2109 in commit 90b73c7b
    
    Change-Id: I74a606d0c5c6e1071e914b4565d825920c71d158
    Reviewed-on: https://gerrit.libreoffice.org/31626
    Reviewed-by: Mike Kaganski <mike.kaganski at collabora.com>
    Tested-by: Mike Kaganski <mike.kaganski at collabora.com>

diff --git a/sw/source/core/layout/tabfrm.cxx b/sw/source/core/layout/tabfrm.cxx
index 97dfccb..af5cf4a 100644
--- a/sw/source/core/layout/tabfrm.cxx
+++ b/sw/source/core/layout/tabfrm.cxx
@@ -517,7 +517,7 @@ static void lcl_PreprocessRowsInCells( SwTabFrame& rTab, SwRowFrame& rLastLine,
             // Check if we can move pTmpLastLineRow to the follow table,
             // or if we have to split the line:
             SwFrame* pCell = pTmpLastLineRow->Lower();
-            bool bTableLayoutToComplex = false;
+            bool bTableLayoutTooComplex = false;
             long nMinHeight = 0;
 
             // We have to take into account:
@@ -533,7 +533,7 @@ static void lcl_PreprocessRowsInCells( SwTabFrame& rTab, SwRowFrame& rLastLine,
                     if ( static_cast<SwCellFrame*>(pCell)->Lower() &&
                          static_cast<SwCellFrame*>(pCell)->Lower()->IsRowFrame() )
                     {
-                        bTableLayoutToComplex = true;
+                        bTableLayoutTooComplex = true;
                         break;
                     }
 
@@ -555,10 +555,10 @@ static void lcl_PreprocessRowsInCells( SwTabFrame& rTab, SwRowFrame& rLastLine,
 
             // 2. Case:
             // The line has to be split, the minimum height still fits into
             // the master table, and the table structure is not to complex.
             if ( nTmpCut > nCurrentHeight ||
                  ( pTmpLastLineRow->IsRowSplitAllowed() &&
-                  !bTableLayoutToComplex && nMinHeight < nTmpCut ) )
+                  !bTableLayoutTooComplex && nMinHeight < nTmpCut ) )
             {
                 // The line has to be split:
                 SwRowFrame* pNewRow = new SwRowFrame( *pTmpLastLineRow->GetTabLine(), &rTab, false );
@@ -555,10 +555,10 @@ static void lcl_PreprocessRowsInCells( SwTabFrame& rTab, SwRowFrame& rLastLine,
             // 2. Case:
             // The line has to be split, the minimum height still fits into
-            // the master table, and the table structure is not to complex.
+            // the master table, and the table structure is not too complex.
             if ( nTmpCut > nCurrentHeight ||
                  ( pTmpLastLineRow->IsRowSplitAllowed() &&


More information about the Libreoffice-commits mailing list